summaryrefslogtreecommitdiffstats
path: root/ingen/GraphObject.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'ingen/GraphObject.hpp')
-rw-r--r--ingen/GraphObject.hpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/ingen/GraphObject.hpp b/ingen/GraphObject.hpp
index 5ad3b156..cca3af45 100644
--- a/ingen/GraphObject.hpp
+++ b/ingen/GraphObject.hpp
@@ -33,7 +33,7 @@ class Edge;
class Plugin;
class Store;
-/** An object on the audio graph - Patch, Block, Port, etc.
+/** An object on the audio graph - Graph, Block, Port, etc.
*
* @ingroup Ingen
*/
@@ -41,7 +41,7 @@ class GraphObject : public Resource
{
public:
enum GraphType {
- PATCH,
+ GRAPH,
BLOCK,
PORT
};
@@ -49,11 +49,11 @@ public:
typedef std::pair<const GraphObject*, const GraphObject*> EdgesKey;
typedef std::map< EdgesKey, SharedPtr<Edge> > Edges;
- // Patches only
+ // Graphs only
Edges& edges() { return _edges; }
const Edges& edges() const { return _edges; }
// Blocks and patches only
virtual uint32_t num_ports() const { return 0; }
virtual GraphObject* port(uint32_t index) const { return NULL; }
virtual const Plugin* plugin() const { return NULL; }
@@ -88,7 +88,7 @@ protected:
: Resource(uris, path_to_uri(path))
{}
- Edges _edges; ///< Patches only
+ Edges _edges; ///< Graphs only
};
} // namespace Ingen
@@ -49,11 +49,11 @@ public:
Edges& edges() { return _edges; }
const Edges& edges() const { return _edges; }
- // Blocks and patches only
+ // Blocks and graphs only
virtual uint32_t num_ports() const { return 0; }
virtual GraphObject* port(uint32_t index) const { return NULL; }